/*  This file is part of FediPotato.
 *  Copyright © 2020 tastytea <tastytea@tastytea.de>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, version 3.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "config.hpp"

#include <fstream>
#include <iomanip>

namespace FediPotato
{

using std::ifstream;
using std::ofstream;
using std::setw;

void Config::read()
{
    if (!fs::exists(_filepath))
    {
        write();
    }

    ifstream file(_filepath);
    // Can't use file.exceptions() because of nlohmann::json's noexceptness.
    // <https://github.com/nlohmann/json#tofrom-streams-eg-files-string-streams>
    if (file.fail() || file.bad())
    {
        throw std::ifstream::failure{
            string("Could not read ") += _filepath, std::io_errc::stream};
    }
    file >> _configfile;
}

void Config::write() const
{
    ofstream file(_filepath);
    if (file.fail() || file.bad())
    {
        throw std::ofstream::failure{
            string("Could not read ") += _filepath, std::io_errc::stream};
    }

    file << setw(4) << _configfile << '\n';
}

} // namespace FediPotato
